@@ -19,10 +19,11 @@ def cli():
 @click.command()
 @click.option('--out', '-o', 'out_file', required=True)
 @click.option('--selector', '-s', required=True)
+@click.option('--remap', default=False)
 @click.argument('in_file', required=True)
-def trend(out_file, selector, in_file):
-    print(out_file, selector, in_file)
-    run_trend(in_file, out_file, selector)
+def trend(out_file, selector, remap, in_file):
+    print(out_file, selector, remap, in_file)
+    run_trend(in_file, out_file, remap, selector)
 
 
 @click.command()
@@ -35,6 +36,12 @@ def pearson(out_file, selector, selector2, in_file):
     run_pearson(in_file, out_file, selector, selector2)
 
 
+def scale():
+    pass
+
+def mask():
+    pass
+
 cli.add_command(trend)
 cli.add_command(pearson)
 
